import { Dimension, Player, world } from "@minecraft/server";
import { MessageFormData, ModalFormData, ActionFormData} from "@minecraft/server-ui";

export function setPerm (target, boolean) {
  target.setOp(boolean)
}

function isNotSelector (text){
    return text.indexOf('@') == -1
}

export function getScore(objective, target, useZero = false) {
    try {
        const oB = world.scoreboard.getObjective(objective)
        if (typeof target == 'string') return oB.getScore(oB.getParticipants().find(pT => pT.displayName == target))
        return oB.getScore(target.scoreboard)
    } catch {
        return useZero ? 0 : NaN
    }
}

export function BoolToNum(boolen){
  return boolen == true ? 1 : 0
}

export function getItemAmounts(player, items) {
  const inv = player.getComponent('inventory')?.container;
  if (!inv) return;
  const counts = {};
  for (let id of items) {
    counts[id] = 0;
  }
  for (let i = 0; i < inv.size; i++) {
    const item = inv.getItem(i);
    if (!item) continue;
    const itemId = item.typeId.replace('minecraft:', '')
    const id = items.find(v => itemId == v.replace('minecraft:', ''))
    if (id) counts[id] += item.amount;
  }
  return counts;
}

export async function runfunction(fname){
    await runcmd(`function ${fname}`, true)
}

export function arrayPlayers(){
  let array = Array.from(world.getPlayers(),plr=>plr.name);
  return array.map(function(playername) { 
    let rand = randomInt(1,3);
    if (rand==1) {
        return `\ue14e ${playername}`
    } else if (rand==2) {
        return `\ue14d ${playername}`
    } else {
        return `\ue13d ${playername}`
    }});
}

export function randomInt(min, max) { 
   return Math.floor(Math.random() * (max - min + 1) + min)
}

export async function runcmd(command, need_log = false){
    try{
        await world.getDimension('overworld').runCommandAsync(command)
    }catch(error){
        if (need_log) {
            console.error(`CMD: ${command}\nError: ${error}`)
        }
    }
}

export async function runcmd_at(name, command){
    if (isNotSelector(name)) {
        await runcmd(`execute as "${name}" at @s positioned as "${name}" run ${command}`)
    } else {
        await runcmd(`execute as ${name} at @s positioned as @s run ${command}`)
    }
}
export async function playsound(sound, name='@a', volume = 1, pitch = 1){
    if (isNotSelector(name)) {
        await runcmd(`execute as "${name}" at "${name}" run playsound ${sound} @s ~~~ ${volume} ${pitch}`)
    } else {
        await runcmd(`execute as ${name} at @s run playsound ${sound} @s ~~~ ${volume} ${pitch}`)
    }
  }

/**
 * Send raw text (@selector support)
 * @param {JSON} rawtext
 * @param {nameTag} player
 */
export async function tellraw(rawtext, name='@a'){
	if (isNotSelector(name)) {
      runcmd(`tellraw "${name}" ${rawtext}`)
    } else {
    	runcmd(`tellraw ${name} ${rawtext}`)
    }
}

/**
 * Send raw text with one element
 * @param {Text} text
 * @param {nameTag} player
 * @param {['text', 'translate']} key
 */
export async function rawtext(text, name='@a', key='text'){
	if (isNotSelector(name)) {
      await runcmd(`tellraw "${name}" {"rawtext":[{"${key}":"${text}"}]}`)
    } else {
    	await runcmd(`tellraw ${name} {"rawtext":[{"${key}":"${text}"}]}`)
    }
}

export async function showCaptcha(target, callback) {

    let name = target.nameTag
    let captcha1_random = randomInt(100, 200)

    const captcha1 = new ModalFormData()
        .title('Captcha #1')
        .slider(`%js.abstractscrpits.captcha.description\n\n\n%gui.select: ${captcha1_random}`, 100, 200, 1)

    let sapling_num = randomInt(0, 6)
    let saplings = ['tile.sapling.acacia.name', 'tile.sapling.big_oak.name', 'tile.sapling.birch.name', 'tile.sapling.jungle.name', 'tile.sapling.oak.name', 'tile.sapling.spruce.name', 'tile.bamboo.name']
    let sapling = saplings[sapling_num]

    const captcha2 = new ActionFormData()
        .title('Captcha #2')
        .body(`%gui.select: %${sapling}`)
        .button('%gui.select', 'textures/blocks/sapling_acacia')
        .button('%gui.select', 'textures/blocks/sapling_roofed_oak')
        .button('%gui.select', 'textures/blocks/sapling_birch')
        .button('%gui.select', 'textures/blocks/sapling_jungle')
        .button('%gui.select', 'textures/blocks/sapling_oak')
        .button('%gui.select', 'textures/blocks/sapling_spruce')
        .button('%gui.select', 'textures/blocks/bamboo_sapling')


    let captcha3_num1 = randomInt(10, 99)
    let captcha3_num2 = randomInt(10, 99)
    let solvesList = [`${captcha3_num1+captcha3_num2}`, `${captcha3_num1+captcha3_num2+randomInt(1, 3)}`, `${captcha3_num1+captcha3_num2+randomInt(1, 10)}`, `${captcha3_num1+captcha3_num2+randomInt(1, 5)}`, `${randomInt(10, 99)+randomInt(10, 99)}`, `${captcha3_num1+captcha3_num2-10}`, `${captcha3_num1+captcha3_num2+10}`]

    function shuffle(array) {
        for (let i = array.length - 1; i > 0; i--) {
          let j = Math.floor(Math.random() * (i + 1));
          [array[i], array[j]] = [array[j], array[i]];
        }
    }
    shuffle(solvesList)

    const captcha3 = new ModalFormData()
      .title('Captcha #3')
      .dropdown(`\n${captcha3_num1}+${captcha3_num2}`, solvesList)

    await captcha1.show(target).then(async r => {
        let [ captcha_test ] = await r.formValues
        if (captcha_test == captcha1_random) {
            await captcha2.show(target).then(async r2 => {
                if (await r2.selection == sapling_num) {
                    await captcha3.show(target).then(async r3 => {
                        let [ captcha2_test ] = await r3.formValues
                        if (solvesList[captcha2_test] == captcha3_num1+captcha3_num2) {
                            try{callback(true)}catch(error){console.warn(error)}
                        } else {
                            tellraw('{"rawtext":[{"text":"§cIncorrect data"}]}', name)
                            try{callback(false)}catch(error){console.warn(error)}
                        }
                    })
                } else {
                    tellraw('{"rawtext":[{"text":"§cIncorrect data"}]}', name)
                    try{callback(false)}catch(error){console.warn(error)}
                }
            })
        } else {
            tellraw('{"rawtext":[{"text":"§cIncorrect data"}]}', name)
            try{callback(false)}catch(error){console.warn(error)}
        }
    })
}

export function showConfirmOpForm(operation, target, dev, callback){
    let tag = hasTag(target, 'global_operator')
    playsound('perm.admin', target.nameTag)
    let pass = randomInt(1000, 9999).toString()
    const admin_modeform = new ModalFormData()
        admin_modeform.title('\ue176 %axiscube.menu.settings.global')
        admin_modeform.textField(`\n${operation} %js.abstractscrpits.global.description\n\n%js.abstractscrpits.dev: [${dev}]\n\ue1fe\n\n%js.abstractscrpits.pin.description`, `${pass}  <--- Your code`)
  
    admin_modeform.show(target).then(gg => {
        let [ input_pass ] = gg.formValues
        if(input_pass == pass && tag == true){
            callback(1)
        } else if (input_pass == pass){
          tellraw('{"rawtext":[{"text":"§c"},{"translate":"xyz.minecrafter.noperm"}]}', target.nameTag, '@s')
        } else if (input_pass != pass){
          tellraw('{"rawtext":[{"text":"§cInvalid password!"}]}', target.nameTag)
        }
    })
}

export function hasTag(target, tag){
  return target.getTags().indexOf(tag) != -1
}

export function textTag(target, tag, text_true, text_false){
  return hasTag(target, tag) ? text_true : text_false
}

