import {ActionFormData,ActionFormResponse,MessageFormData,ModalFormData} from "@minecraft/server-ui";
import {Dimension,Player,world} from "@minecraft/server";
import {getItemAmounts, getScore, playsound, runcmd, runcmd_at, tellraw, textTag} from '../AbstractTools.js'
import {setting_bw} from '../ui/settings.js'

function check_res(check_res_count, check_res_price, check_res_if='', check_res_else='§c') {
    if (check_res_count >= check_res_price) {return check_res_if} else {return check_res_else}
}

if (getScore('debug', 'minigame') == 11){

world.events.beforeItemUse.subscribe(eventData => {
    if (eventData.item.typeId == "mcxyz:settings" && getScore('debug', 'minigame') == 11) {
        setting_bw(eventData.source, eventData.source.nameTag)
    }
})

const UNICODES = {
    'copper_ingot': '\ue186',
    'iron_ingot': '\ue166',
    'gold_ingot': '\ue186',
    'amethyst_shard': '\ue167'
}

const CAN_DESTROY = '{"minecraft:can_destroy":{"blocks":["planks","web","obsidian","sandstone","end_stone"]}}'
const CAN_PLACE = '{"can_place_on":{"blocks":["stone", "wool", "podzol", "planks", "dirt", "grass", "log", "leaves", "leaves2", "log2", "sandstone", "bedrock", "bed", "wooden_slab", "wood","obsidian","web","stripped_spruce_log","end_stone"]}}'

function buy_item(target, br_res_has, br_res_type, br_item_price, br_item_type, br_item_count, br_item_id, br_item_comp, linkto=0) {
    let name = target.nameTag
    if (br_res_has >= br_item_price) {
        runcmd(`clear "${name}" ${br_res_type} -1 ${br_item_price}`);
        runcmd(`give "${name}" ${br_item_type} ${br_item_count} ${br_item_id} ${br_item_comp}`);
        playsound('mob.villager.yes', name)
        summon_form(target, linkto)
    } else {
        tellraw(`{"rawtext":[{"text":"§c"},{"translate":"axiscube.bw.shop.too_expensive","with":{"rawtext":[{"text":"${br_res_has}"},{"text":"${br_item_price}"},{"text":"${UNICODES[br_res_type]}"}]}}]}`,name);
        playsound('block.false_permissions', name)
        summon_form(target, linkto)
    }
}

function buy_item_structure(target, br_res_has, br_res_type, br_item_price, br_item_strname, linkto=0) {
    let name = target.nameTag
    if (br_res_has >= br_item_price) {
        runcmd(`clear "${name}" ${br_res_type} -1 ${br_item_price}`);
        runcmd(`execute  as "${name}" at "${name}" run structure load ${br_item_strname} ~~~`);
        playsound('mob.villager.yes', name)
        summon_form(target, linkto)
    } else {
        tellraw(`{"rawtext":[{"text":"§c"},{"translate":"axiscube.bw.shop.too_expensive","with":{"rawtext":[{"text":"${br_res_has}"},{"text":"${br_item_price}"},{"text":"${UNICODES[br_res_type]}"}]}}]}`,name);
        playsound('block.false_permissions', name)
        summon_form(target, linkto)
    }
}

function buy_item_cmds(target, br_res_has, br_res_type, br_item_price, cmds,linkto=0) {
    let name = target.nameTag
    if (br_res_has >= br_item_price) {
        runcmd(`clear "${name}" ${br_res_type} -1 ${br_item_price}`);
        for (let i = 0; i != cmds.length; i++) {
            runcmd(`execute  as "${name}" at "${name}" run ${cmds[i]}`, true)
        }
        playsound('mob.villager.yes', name)
        summon_form(target,linkto)
    } else {
        tellraw(`{"rawtext":[{"text":"§c"},{"translate":"axiscube.bw.shop.too_expensive","with":{"rawtext":[{"text":"${br_res_has}"},{"text":"${br_item_price}"},{"text":"${UNICODES[br_res_type]}"}]}}]}`,name);
        playsound('block.false_permissions', name)
        summon_form(target,linkto)
    }
}

function bw_shop_slider(target, item_name, item_id, item_data, item_components, item_price, item_step, res_type, res_var, linkto=0){
    let name = target.nameTag
    if (res_var > item_price) {
        let item_max
        let item_bill
        item_max = res_var/item_price
        item_bill = Math.floor(item_max)
        item_bill = item_bill*item_price
        item_max = Math.floor(item_max)
        item_max = item_step*item_max
        
        const bw_shop_sliderform = new ModalFormData()
            .title('%skins.buy.buyButton')
            .slider(`%${item_name}`, item_step, item_max, item_step, item_step)

        bw_shop_sliderform.show(target).then(gg => {
            let [item_count] = gg.formValues
            var item_total = item_count/item_step*item_price
            runcmd(`clear "${name}" ${res_type} -1 ${item_total}`)
            runcmd(`give "${name}" ${item_id} ${item_count} ${item_data} ${item_components}`)
            playsound('mob.villager.yes', name)
            summon_form(target,linkto)
        })
    } else {
        tellraw(`{"rawtext":[{"text":"§c"},{"translate":"axiscube.bw.shop.too_expensive","with":{"rawtext":[{"text":"${res_var}"},{"text":"${item_price}"}]}}]}`,name);
        playsound('block.false_permissions', name)
        summon_form(target,linkto)
    }
}

function summon_form(target, linkto=0) {
    let name = target.nameTag

    let res_amounts = getItemAmounts(target, ["copper_ingot", "amethyst_shard", "gold_ingot", "iron_ingot"])
    let current_res = `§6${res_amounts.copper_ingot} \ue186 §8${res_amounts.iron_ingot} \ue166 §g${res_amounts.gold_ingot} \ue165 §5${res_amounts.amethyst_shard} \ue167`

    function formlink(fs) {
        switch(fs) {
            case 0:
                const bw_shop = new ActionFormData()
                    .title("%js.abstractscripts.bw.shop")
                    .body(current_res)
                    .button("%howtoplay.weapons", "textures/items/gold_sword")
                    .button("%howtoplay.armor", "textures/items/chainmail_chestplate")
                    .button("%howtoplay.blocks & %itemGroup.name.pickaxe", "textures/items/diamond_pickaxe")
                    .button("%js.abstractscripts.bw.other", "textures/items/ender_pearl")
                bw_shop.show(target).then(r => {
                    if (r.selection == 0) {
                        formlink(1);
                    } else if (r.selection == 1) {
                        formlink(2);
                    } else if (r.selection == 2) {
                        formlink(3);
                    } else if (r.selection == 3) {
                        formlink(4);
                    } else if (r.selection == 4) {
                        formlink(6);
                    }
                });
                break;
            case 1:
                const bw_shop_weapons = new ActionFormData()
                    .title("%js.abstractscripts.bw.shop - %howtoplay.weapons")
                    .body(current_res)
                    .button('%gui.back', `textures/ui/icons/back.png`)
                    .button(`${check_res(res_amounts.copper_ingot, 10)}%item.stick.name (%enchantment.knockback)\n§l§610 §r\ue186`, "textures/items/baseball_bat.png")
                    .button(`${check_res(res_amounts.iron_ingot, 7)}%item.stone_sword.name\n§l§87 §r\ue166`, "textures/items/stone_sword")
                    .button(`${check_res(res_amounts.gold_ingot, 7)}%item.iron_sword.name\n§l§g7 §r\ue165`, "textures/items/iron_sword")
                    .button(`${check_res(res_amounts.amethyst_shard, 7)}%item.diamond_sword.name\n§l§57 §r\ue167`, "textures/items/diamond_sword")
                    .button(`${check_res(res_amounts.gold_ingot, 10)}%item.bow.name\n§l§g10 §r\ue165`, "textures/items/bow_standby")
                    .button(`${check_res(res_amounts.amethyst_shard, 10)}%item.bow.name (%enchantment.arrowDamage %enchantment.level.3) \n§l§510 §r\ue167`, "textures/items/bow_pulling_1")
                    .button(`${check_res(res_amounts.amethyst_shard, 10)}%item.bow.name (%enchantment.arrowKnockback %enchantment.level.1) \n§l§510 §r\ue167`, "textures/items/bow_pulling_2")
                    .button(`${check_res(res_amounts.gold_ingot, 8)}%item.arrow.name (x12) \n§l§g8 §r\ue165`, "textures/items/arrow")

                bw_shop_weapons.show(target).then(gg => {
                    if (gg.selection == 0) {
                        summon_form(target,0)
                    } else if (gg.selection == 1) {
                        buy_item_structure(target, res_amounts.copper_ingot, 'copper_ingot', 10, 'bw_item_baseball_bat',1)
                    } else if (gg.selection == 2) {
                        buy_item(target, res_amounts.iron_ingot, 'iron_ingot', 7, 'stone_sword', 1, 0, '',1)
                    } else if (gg.selection == 3) {
                        buy_item(target, res_amounts.gold_ingot, 'gold_ingot', 7, 'iron_sword', 1, 0, '',1)
                    } else if (gg.selection == 4) {
                        buy_item(target, res_amounts.amethyst_shard, 'amethyst_shard', 7, 'diamond_sword', 1, 0, '',1)
                    } else if (gg.selection == 5) {
                        buy_item(target, res_amounts.gold_ingot, 'gold_ingot', 10, 'bow', 1, 0, '',1)
                    } else if (gg.selection == 6) {
                        buy_item(target, res_amounts.gold_ingot, 'gold_ingot', 10, 'bow', 1, 0, '',1)
                    } else if (gg.selection == 7) {
                        buy_item_structure(target, res_amounts.amethyst_shard, 'amethyst_shard', 10, 'bw_item_bow3',1)
                    } else if (gg.selection == 8) {
                        buy_item_structure(target, res_amounts.amethyst_shard, 'amethyst_shard', 10, 'bw_item_bow_punch',1)
                    } else if (gg.selection == 9) {
                        bw_shop_slider(target, 'item.arrow.name', 'arrow', 0, '', 8, 12, 'gold_ingot', res_amounts.gold_ingot,1)
                    }
                })
                break;
            case 2:
                const bw_shop_armor = new ActionFormData()
                    .title("%js.abstractscripts.bw.shop - %howtoplay.armor")
                    .body(current_res)
                    .button('%gui.back', `textures/ui/icons/back.png`)
                    .button(`${check_res(res_amounts.copper_ingot, 20)}%howtoplay.armor (%item.leather.name)\n§l§620 §r\ue186`, "textures/ui/icons/items/leather_set.png")
                    .button(`${check_res(res_amounts.copper_ingot, 5)}%item.leather_helmet.name\n§l§65 §r\ue186`, "textures/ui/icons/items/leather_helmet.png")
                    .button(`${check_res(res_amounts.copper_ingot, 5)}%item.leather_chestplate.name\n§l§65 §r\ue186`, "textures/ui/icons/items/leather_chestplate.png")
                    .button(`${check_res(res_amounts.copper_ingot, 5)}%item.leather_leggings.name\n§l§65 §r\ue186`, "textures/ui/icons/items/leather_leggings.png")
                    .button(`${check_res(res_amounts.copper_ingot, 5)}%item.leather_boots.name\n§l§65 §r\ue186`, "textures/ui/icons/items/leather_boots.png")
                    .button(`${check_res(res_amounts.iron_ingot, 5)}%item.chainmail_helmet.name\n§l§85 §r\ue166`, "textures/items/chainmail_helmet")
                    .button(`${check_res(res_amounts.iron_ingot, 8)}%item.chainmail_chestplate.name\n§l§88 §r\ue166`, "textures/items/chainmail_chestplate")
                    .button(`${check_res(res_amounts.gold_ingot, 16)}%item.iron_leggings.name\n§l§g16 §r\ue165`, "textures/items/iron_leggings")
                    .button(`${check_res(res_amounts.amethyst_shard, 4)}%item.diamond_boots.name\n§l§54 §r\ue167`, "textures/items/diamond_boots")
                    .button(`${check_res(res_amounts.amethyst_shard, 6)}%item.netherite_helmet.name\n§l§56 §r\ue167`, "textures/items/netherite_helmet")
                bw_shop_armor.show(target).then(gg => {
                    if (gg.selection == 0) {
                        summon_form(target,0)
                    } if (gg.selection == 1) {
                        buy_item_cmds(target, res_amounts.copper_ingot, 'copper_ingot', 20, [`execute  as "${name}" at "${name}" run function zz_games/bw/shop/buy_leatherset`],2)
                    } else if (gg.selection == 2) {
                        buy_item_cmds(target, res_amounts.copper_ingot, 'copper_ingot', 5, [`scoreboard players set "${name}" debug2 1`,`execute  as "${name}" at "${name}" run function zz_games/bw/shop/buy_armor`],2)
                    } else if (gg.selection == 3) {
                        buy_item_cmds(target, res_amounts.copper_ingot, 'copper_ingot', 5, [`scoreboard players set "${name}" debug2 2`,`execute  as "${name}" at "${name}" run function zz_games/bw/shop/buy_armor`],2)
                    } else if (gg.selection == 4) {
                        buy_item_cmds(target, res_amounts.copper_ingot, 'copper_ingot', 5, [`scoreboard players set "${name}" debug2 3`,`execute  as "${name}" at "${name}" run function zz_games/bw/shop/buy_armor`],2)
                    } else if (gg.selection == 5) {
                        buy_item_cmds(target, res_amounts.copper_ingot, 'copper_ingot', 5, [`scoreboard players set "${name}" debug2 4`,`execute  as "${name}" at "${name}" run function zz_games/bw/shop/buy_armor`],2)
                    } else if (gg.selection == 6) {
                        buy_item_cmds(target, res_amounts.iron_ingot, 'iron_ingot', 5, [`scoreboard players set "${name}" debug2 5`,`execute  as "${name}" at "${name}" run function zz_games/bw/shop/buy_armor`],2)
                    } else if (gg.selection == 7) {
                        buy_item_cmds(target, res_amounts.iron_ingot, 'iron_ingot', 8, [`scoreboard players set "${name}" debug2 6`,`execute  as "${name}" at "${name}" run function zz_games/bw/shop/buy_armor`],2)
                    } else if (gg.selection == 8) {
                        buy_item_cmds(target, res_amounts.gold_ingot, 'gold_ingot', 16, [`scoreboard players set "${name}" debug2 7`,`execute  as "${name}" at "${name}" run function zz_games/bw/shop/buy_armor`],2)
                    } else if (gg.selection == 9) {
                        buy_item_cmds(target, res_amounts.amethyst_shard, 'amethyst_shard', 4, [`scoreboard players set "${name}" debug2 8`,`execute  as "${name}" at "${name}" run function zz_games/bw/shop/buy_armor`],2)
                    } else if (gg.selection == 10) {
                        buy_item_cmds(target, res_amounts.amethyst_shard, 'amethyst_shard', 5, [`scoreboard players set "${name}" debug2 9`,`execute  as "${name}" at "${name}" run function zz_games/bw/shop/buy_armor`],2)
                    }
                });
                break;
            case 3:
                const bw_shop_blocks = new ActionFormData()
                    .title("%js.abstractscripts.bw.shop - %howtoplay.blocks & %itemGroup.name.pickaxe")
                    .body(current_res)
                    .button('%gui.back', `textures/ui/icons/back.png`)
                    .button(`${check_res(res_amounts.copper_ingot, 4)}%tile.sandstone.name (x8)\n§l§64 §r\ue186`, "textures/blocks/sandstone_smooth")
                    .button(`${check_res(res_amounts.iron_ingot, 5)}%tile.end_stone.name (x8)\n§l§85 §r\ue166`, "textures/blocks/end_stone")
                    .button(`${check_res(res_amounts.iron_ingot, 5)}%tile.planks.name (x8)\n§l§85 §r\ue166`, "textures/blocks/planks_oak")
                    .button(`${check_res(res_amounts.gold_ingot, 3)}%tile.web.name (x1)\n§l§g3 §r\ue165`, "textures/blocks/web")
                    .button(`${check_res(res_amounts.amethyst_shard, 1)}%tile.obsidian.name (x1)\n§l§51 §r\ue167`, "textures/blocks/obsidian")
                    .button(`${check_res(res_amounts.iron_ingot, 4)}%item.stone_pickaxe.name\n§l§84 §r\ue166`, "textures/items/stone_pickaxe")
                    .button(`${check_res(res_amounts.gold_ingot, 5)}%item.iron_pickaxe.name\n§l§g5 §r\ue165`, "textures/items/iron_pickaxe")
                    .button(`${check_res(res_amounts.amethyst_shard, 4)}%item.diamond_pickaxe.name\n§l§54 §r\ue167`, "textures/items/diamond_pickaxe")
                    .button(`${check_res(res_amounts.iron_ingot, 5)}%item.stone_axe.name\n§l§55 §r\ue166`, "textures/items/stone_axe")
                    .button(`${check_res(res_amounts.amethyst_shard, 5)}%item.diamond_pickaxe.name\n§l§55 §r\ue167`, "textures/items/diamond_axe")

                bw_shop_blocks.show(target).then(gg => {
                    if (gg.selection == 0) {
                        summon_form(target,0)
                    } if (gg.selection == 1) {
                        bw_shop_slider(target, 'tile.sandstone.name', 'sandstone', 2, CAN_PLACE, 4, 8, 'copper_ingot', res_amounts.copper_ingot,3)
                    } else if (gg.selection == 2) {
                        bw_shop_slider(target, 'tile.end_stone.name', 'end_stone', 0, CAN_PLACE, 5, 8, 'iron_ingot', res_amounts.iron_ingot,3)
                    } else if (gg.selection == 3) {
                        bw_shop_slider(target, 'tile.planks.name', 'planks', 0, CAN_PLACE, 5, 8, 'iron_ingot', res_amounts.iron_ingot,3)
                    } else if (gg.selection == 4) {
                        bw_shop_slider(target, 'tile.web.name', 'web', 0, CAN_PLACE, 3, 1, 'gold_ingot', res_amounts.gold_ingot,3)
                    } else if (gg.selection == 5) {
                        bw_shop_slider(target, 'tile.obsidian.name', 'obsidian', 0, CAN_PLACE, 1, 1, 'amethyst_shard', res_amounts.amethyst_shard,3)
                    } else if (gg.selection == 6) {
                        buy_item(target, res_amounts.iron_ingot, 'iron_ingot', 4, 'stone_pickaxe', 1, 0, CAN_DESTROY,3)
                    } else if (gg.selection == 7) {
                        buy_item(target, res_amounts.gold_ingot, 'gold_ingot', 4, 'iron_pickaxe', 1, 0, CAN_DESTROY,3)
                    } else if (gg.selection == 8) {
                        buy_item(target, res_amounts.amethyst_shard, 'amethyst_shard', 4, 'diamond_pickaxe', 1, 0, CAN_DESTROY,3)
                    }
                });
                break;
            case 4:
                const bw_shop_other = new ActionFormData()
                    .title("%js.abstractscripts.bw.shop - %js.abstractscripts.bw.other")
                    .body(current_res)
                    .button('%gui.back', `textures/ui/icons/back.png`)
                    .button(`${check_res(res_amounts.gold_ingot, 1)}%item.snowball.name (x4)\n§l§g1 §r\ue165`, "textures/items/snowball")
                    .button(`${check_res(res_amounts.amethyst_shard, 3)}%item.feather.name (%potion.levitation)\n§l§54 §r\ue167`, "textures/items/feather")
                    .button(`${check_res(res_amounts.amethyst_shard, 1)}%item.gold_ingot.name (x3)\n§l§51 §r\ue167`, "textures/items/gold_ingot")
                    .button(`${check_res(res_amounts.gold_ingot, 1)}%item.iron_ingot.name (x5)\n§l§g1 §r\ue165`, "textures/items/iron_ingot")
                    .button(`${check_res(res_amounts.amethyst_shard, 8)}Wand (%potion.regeneration)\n§l§58 §r\ue167`, "textures/ui/icons/items/regen_wand.png")
                    .button(`${check_res(res_amounts.amethyst_shard, 6)}Wand (%potion.invisibility)\n§l§56 §r\ue167`, "textures/items/invisibility_wand.png")
                
                bw_shop_other.show(target).then(gg => {
                    if (gg.selection == 0) {
                        summon_form(target,0)
                    } if (gg.selection == 1) {
                        bw_shop_slider(target, 'item.snowball.name', 'snowball', 0, '', 1, 4, 'gold_ingot', res_amounts.gold_ingot,4)
                    } else if (gg.selection == 2) {
                        bw_shop_slider(target, 'item.feather.name', 'mcxyz:levitation_item', 0, '', 4, 1, 'amethyst_shard', res_amounts.amethyst_shard,4)
                    } else if (gg.selection == 3) {
                        bw_shop_slider(target, 'item.gold_ingot.name', 'gold_ingot', 0, '', 1, 3, 'amethyst_shard', res_amounts.amethyst_shard,4)
                    } else if (gg.selection == 4) {
                        bw_shop_slider(target, 'item.iron_ingot.name', 'iron_ingot', 0, '', 1, 5, 'gold_ingot', res_amounts.gold_ingot,4)
                    } else if (gg.selection == 5) {
                        buy_item(target, res_amounts.amethyst_shard, 'amethyst_shard', 8, 'mcxyz_test:regen_wand', 1, 0, CAN_DESTROY,4)
                    } else if (gg.selection == 6) {
                        buy_item(target, res_amounts.amethyst_shard, 'amethyst_shard', 6, 'mcxyz_test:inv_wand', 1, 0, CAN_DESTROY,4)
                    }
                });
                break;
        }
    }
    formlink(linkto)
}

world.events.entityHit.subscribe(({ hitEntity, entity }) => {
    if (entity && hitEntity && entity.typeId == "minecraft:player" && hitEntity.typeId == "mcxyz:seller" /*&& getScore('debug', 'minigame') == 11*/) {
        summon_form(entity)
    }
})


world.events.beforeItemUse.subscribe(eventData2 => {
    if (eventData2.item.typeId == "mcxyz:kitselection_item" && getScore('debug', 'minigame') == 11) {
        const name = eventData2.source.nameTag
        const target2f = eventData2.source

        const bw_kitsel = new ActionFormData()
        .title("Starter kit")
        .body("%xyz.minecrafter.bw.select_kitstart")
        .button(`%item.wooden_pickaxe.name`, "textures/items/wood_pickaxe")
        .button(`${textTag(target2f, 'bw_kit_killer', '\ue1c9 ', '')}%item.stone_sword.name`, "textures/items/stone_sword")
        .button(`${textTag(target2f, 'bw_kit_bob', '\ue1c9 ', '')}%howtoplay.blocks`, "textures/ui/icons/sandstone.png")
        .button(`${textTag(target2f, 'bw_kit_chef', '\ue1c9 ', '')}%item.bread.name`, "textures/items/bread")


        bw_kitsel.show(eventData2.source).then(r => {
            if (r.selection == 0) {
                runcmd_at(name,`tag @s remove bw_kit_chef`);
                runcmd_at(name,`tag @s remove bw_kit_bob`);
                runcmd_at(name,`tag @s remove bw_kit_killer`);
            } else if (r.selection == 1) {
                runcmd_at(name,`tag @s remove bw_kit_chef`);
                runcmd_at(name,`tag @s remove bw_kit_bob`);
                runcmd_at(name,`tag @s add bw_kit_killer`);
            } else if (r.selection == 2) {
                runcmd_at(name,`tag @s remove bw_kit_chef`);
                runcmd_at(name,`tag @s add bw_kit_bob`);
                runcmd_at(name,`tag @s remove bw_kit_killer`);
            } else if (r.selection == 3) {
                runcmd_at(name,`tag @s add bw_kit_chef`);
                runcmd_at(name,`tag @s remove bw_kit_bob`);
                runcmd_at(name,`tag @s remove bw_kit_killer`);
            }
        })

    }
})


world.events.beforeItemUse.subscribe(eventData3 => {
    if (eventData3.item.typeId == "mcxyz:bw_team_selector" && getScore('debug', 'minigame') == 11) {

        const bw_teamsel = new ActionFormData()
        .title("%xyz.minecrafter.bw.select_your_team.name")
        .body("%xyz.minecrafter.bw.select_your_team")
        .button("§4%color.red", "textures/ui/icons/team/red.png")
        .button("§1%color.blue", "textures/ui/icons/team/blue.png")
        .button("§2%color.green", "textures/ui/icons/team/green.png")
        .button("§g%color.yellow", "textures/ui/icons/team/yellow.png")

        const name = eventData3.source.nameTag
        const target = eventData3.source

        bw_teamsel.show(eventData3.source).then(r => {
            if (r.selection == 0) {
                runcmd_at(name,`function zz_games/bw/team_select/red`);
            } else if (r.selection == 1) {
                runcmd_at(name,`function zz_games/bw/team_select/blue`);
            } else if (r.selection == 2) {
                runcmd_at(name,`function zz_games/bw/team_select/green`);
            } else if (r.selection == 3) {
                runcmd_at(name,`function zz_games/bw/team_select/yellow`);
            }
        })
    }
})
}
