import { Dimension, Player, world } from "@minecraft/server";
import {
    ActionFormData,
    ActionFormResponse,
    MessageFormData,
    ModalFormData
  } from "@minecraft/server-ui";
import { death_effects } from "../ui/death_effects.js";
import {randomInt, runcmd, getScore, hasTag} from "../AbstractTools.js";
import { report_form } from "../ui/info.js";
import { music_settings } from "../ui/settings.js";

function inv_status(tru, fls) {
    if (getScore('settings', 'inv') == 1) {
        return tru
    } else {
        return fls
    }
}

function deathrun_skull(target) {
    let name = target.nameTag
    const deathrun_skull = new ActionFormData()
        .title("%DeathRun")
        .body("%menu.game - DeathRun")
        .button("%item.skull.skeleton.name", "textures/ui/icons/skin_picture/skeleton.png")
        .button("%item.skull.zombie.name", "textures/ui/icons/skin_picture/zombie.png")
        .button("%item.skull.creeper.name", "textures/ui/icons/skin_picture/creeper.png")
        .button("%item.skull.wither.name", "textures/ui/icons/skin_picture/wither_skeleton.png")
        .button("%item.skull.dragon.name", "textures/ui/icons/skin_picture/unknown.png")

        deathrun_skull.show(target).then(r => {
            if (r.selection == 0) {
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_dragon`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_creeper`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_blackskeleton`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_zombie`)}catch(error){}
                runcmd(`tellraw "${name}" {"rawtext":[{"text":"§c","translate":"xyz.minecrafter.msg.menu.settings.reset_generic"}]}`)
                runcmd(`replaceitem entity @a[tag=dead,name="${name}"] slot.armor.head 0 skull 1 0 {"minecraft:item_lock":{"mode":"lock_in_slot"}}`)
            } else if (r.selection == 1) {
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_dragon`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_creeper`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_blackskeleton`)}catch(error){}
                try{runcmd(`tag "${name}" add deathrun_skull_zombie`)}catch(error){}
                runcmd(`replaceitem entity @a[tag=dead,name="${name}"] slot.armor.head 0 skull 1 2 {"minecraft:item_lock":{"mode":"lock_in_slot"}}`)
            } else if (r.selection == 2) {
                try{runcmd(`tag "${name}" add deathrun_skull_creeper`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_dragon`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_blackskeleton`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_zombie`)}catch(error){}
                runcmd(`replaceitem entity @a[tag=dead,name="${name}"] slot.armor.head 0 skull 1 4 {"minecraft:item_lock":{"mode":"lock_in_slot"}}`)
            } else if (r.selection == 3) {
                try{runcmd(`tag "${name}" add deathrun_skull_blackskeleton`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_dragon`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_creeper`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_zombie`)}catch(error){}
                runcmd(`replaceitem entity @a[tag=dead,name="${name}"] slot.armor.head 0 skull 1 1 {"minecraft:item_lock":{"mode":"lock_in_slot"}}`)
            } else if (r.selection == 4) {
                try{runcmd(`tag "${name}" add deathrun_skull_dragon`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_creeper`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_blackskeleton`)}catch(error){}
                try{runcmd(`tag @a[name="${name}"] remove deathrun_skull_zombie`)}catch(error){}
                runcmd(`replaceitem entity @a[tag=dead,name="${name}"] slot.armor.head 0 skull 1 5 {"minecraft:item_lock":{"mode":"lock_in_slot"}}`)
            }
        })
}

function deathrun_skull_img_path(target) {
    if (hasTag(target, 'deathrun_skull_zombie')) {
        return 'zombie'
    } else if (hasTag(target, 'deathrun_skull_creeper')) {
        return 'creeper'
    } else if (hasTag(target, 'deathrun_skull_blackskeleton')) {
        return 'wither_skeleton'
    } else {
        return 'skeleton'
    }
}

world.events.beforeItemUse.subscribe(eventData => {
    const player = eventData.source.nameTag
    const target = eventData.source
    let game_id = getScore('debug', 'minigame')
    if (eventData.item.typeId == "mcxyz:game_menu" && game_id == 10) {
        const gmenu_dr = new ActionFormData()
        .title("DeathRun")
        .body("%menu.game - %xyz.minecrafter.mg.deathrun")
        .button("%xyz.minecrafter.stopgame", "textures/ui/icons/stopgame.png")
        .button("%xyz.minecrafter.particles_menu.name", "textures/ui/icons/particles.png")
        .button("%item.skull.char.name", `textures/ui/icons/skin_picture/${deathrun_skull_img_path(target)}.png`)
        .button("%options.music", "textures/ui/icons/music.png")
        .button("%xyz.minecrafter.game_menu.report", "textures/ui/icons/bug.png")
        .button("debug.info", "textures/ui/icons/console.png")

        gmenu_dr.show(eventData.source).then(r => {
            if (r.selection == 0) {
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run stopsound @a`)
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run setblock 19 1 19 redstone_block`)
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run tellraw @a {"rawtext":[{"translate":"xyz.minecrafter.msg.stopgame","with":{"rawtext":[{"selector":"@s"}]}}]}`)
                runcmd(`execute as @a[name="${player}",tag=!perm_stopgame] at @a[name="${player}",tag=!perm_stopgame] run function zz_other/stopgame_noperm`)
            } else if (r.selection == 1) {
                death_effects(target)
            } else if (r.selection == 2) {
                deathrun_skull(target)
            } else if (r.selection == 3) {
                music_settings(target)
            } else if (r.selection == 4) {
                report_form(target)
            } else if (r.selection == 5) {
                runcmd(`execute as @a[name="${player}"] at @a[name="${player}"] run function zz_lk/debug`)
            }
        })
    } else if (eventData.item.typeId == "mcxyz:game_menu" && game_id == 13) {
        const gmenu_prk = new ActionFormData()
        .title("%xyz.minecrafter.mg.prk")
        .body("%menu.game - %xyz.minecrafter.mg.prk")
        .button("%xyz.minecrafter.stopgame", "textures/ui/icons/stopgame.png")
        .button(`%potion.invisibility\n§r(${inv_status('§2%addServer.resourcePack.enabled§r', '§4%addServer.resourcePack.disabled§r')})`, "textures/ui/icons/inv.png")
        .button("%options.music", "textures/ui/icons/music.png")
        .button("%xyz.minecrafter.game_menu.report", "textures/ui/icons/bug.png")
        .button("debug.info", "textures/ui/icons/console.png")

        gmenu_prk.show(target).then(r => {
            if (r.selection == 0) {
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run stopsound @a`)
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run setblock 31 1 -15 redstone_block`)
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run tellraw @a {"rawtext":[{"translate":"xyz.minecrafter.msg.stopgame","with":{"rawtext":[{"selector":"@s"}]}}]}`)
                runcmd(`execute as @a[name="${player}",tag=!perm_stopgame] at @a[name="${player}",tag=!perm_stopgame] run function zz_other/stopgame_noperm`)
            } else if (r.selection == 1) {
                runcmd(`execute as @a[name="${player}",tag=perm_managegame] at @a[name="${player}",tag=perm_managegame] run setblock -28 1 -22 redstone_block`)
                if (getScore('settings', 'inv') == 1) {
                    runcmd('scoreboard players set "inv" settings 0')
                } else {
                    runcmd('scoreboard players set "inv" settings 1')
                }
                runcmd(`execute as @a[name="${player}",tag=!perm_managegame] at @a[name="${player}",tag=!perm_managegame] run tellraw @s {"rawtext":[{"text":"§c"},{"translate":"xyz.minecrafter.noperm"}]}`)
            } else if (r.selection == 2) {
                music_settings(target)
            } else if (r.selection == 3) {
                report_form(target)
            } else if (r.selection == 4) {
                runcmd(`execute as @a[name="${player}"] at @a[name="${player}"] run function zz_lk/debug`)
            }
        })
    } else if (eventData.item.typeId == "mcxyz:game_menu" && game_id == 1) {
        const gmenu_mn = new ActionFormData()
        .title("%xyz.minecrafter.mg.mn")
        .body("%menu.game - %xyz.minecrafter.mg.mn")
        .button("%xyz.minecrafter.stopgame", "textures/ui/icons/stopgame.png")
        .button("%xyz.minecrafter.particles_menu.name", "textures/ui/icons/particles.png")
        .button(`%potion.invisibility\n§r(${inv_status('§2%addServer.resourcePack.enabled§r', '§4%addServer.resourcePack.disabled§r')})`, "textures/ui/icons/inv.png")
        .button("%options.music", "textures/ui/icons/music.png")
        .button("%xyz.minecrafter.game_menu.report", "textures/ui/icons/bug.png")
        .button("debug.info", "textures/ui/icons/console.png")

        gmenu_mn.show(target).then(r => {
            if (r.selection == 0) {
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run stopsound @a`)
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run setblock -28 1 -15 redstone_block`)
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run tellraw @a {"rawtext":[{"translate":"xyz.minecrafter.msg.stopgame","with":{"rawtext":[{"selector":"@s"}]}}]}`)
                runcmd(`execute as @a[name="${player}",tag=!perm_stopgame] at @a[name="${player}",tag=!perm_stopgame] run function zz_other/stopgame_noperm`)
            } else if (r.selection == 1) {
                death_effects(target)
            } else if (r.selection == 2) {
                runcmd(`execute as @a[name="${player}",tag=perm_managegame] at @a[name="${player}",tag=perm_managegame] run setblock -28 1 -22 redstone_block`)
                if (getScore('settings', 'inv') == 1) {
                    runcmd('scoreboard players set "inv" settings 0')
                } else {
                    runcmd('scoreboard players set "inv" settings 1')
                }
                runcmd(`execute as @a[name="${player}",tag=!perm_managegame] at @a[name="${player}",tag=!perm_managegame] run tellraw @s {"rawtext":[{"text":"§c"},{"translate":"xyz.minecrafter.noperm"}]}`)
            } else if (r.selection == 3) {
                music_settings(target)
            } else if (r.selection == 4) {
                report_form(target)
            } else if (r.selection == 5) {
                runcmd(`execute as @a[name="${player}"] at @a[name="${player}"] run function zz_lk/debug`)
            }
        })
    } else if (eventData.item.typeId == "mcxyz:game_menu" && game_id == 9) {
        const gmenu_drop = new ActionFormData()
        .title("%xyz.minecrafter.mg.dropper")
        .body("%menu.game - %xyz.minecrafter.mg.dropper")
        .button("%xyz.minecrafter.stopgame", "textures/ui/icons/stopgame.png")
        .button("%xyz.minecrafter.particles_menu.name", "textures/ui/icons/particles.png")
        .button(`%potion.invisibility\n§r(${inv_status('§2%addServer.resourcePack.enabled§r', '§4%addServer.resourcePack.disabled§r')})`, "textures/ui/icons/inv.png")
        .button("%xyz.minecrafter.game_menu.report", "textures/ui/icons/bug.png")
        .button("debug.info", "textures/ui/icons/console.png")

        gmenu_drop.show(target).then(r => {
            if (r.selection == 0) {
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run stopsound @a`)
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run setblock 20 1 -1 redstone_block`)
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run tellraw @a {"rawtext":[{"translate":"xyz.minecrafter.msg.stopgame","with":{"rawtext":[{"selector":"@s"}]}}]}`)
                runcmd(`execute as @a[name="${player}",tag=perm_stopgame] at @a[name="${player}",tag=perm_stopgame] run function zz_dev_tplobby`)
                runcmd(`execute as @a[name="${player}",tag=!perm_stopgame] at @a[name="${player}",tag=!perm_stopgame] run function zz_other/stopgame_noperm`)
            } else if (r.selection == 1) {
                death_effects(target)
            } else if (r.selection == 2) {
                runcmd(`execute as @a[name="${player}",tag=perm_managegame] at @a[name="${player}",tag=perm_managegame] run setblock -28 1 -22 redstone_block`)
                if (getScore('settings', 'inv') == 1) {
                    runcmd('scoreboard players set "inv" settings 0')
                } else {
                    runcmd('scoreboard players set "inv" settings 1')
                }
                runcmd(`execute as @a[name="${player}",tag=!perm_managegame] at @a[name="${player}",tag=!perm_managegame] run tellraw @s {"rawtext":[{"text":"§c"},{"translate":"xyz.minecrafter.noperm"}]}`)
            } else if (r.selection == 3) {
                report_form(target)
            } else if (r.selection == 4) {
                runcmd(`execute as @a[name="${player}"] at @a[name="${player}"] run function zz_lk/debug`)
            }
        })
    } else if (eventData.item.typeId == "mcxyz:drop_location_selector") {
        let doors = ['door_spruce', 'door_iron', 'door_acacia', 'door_jungle', 'door_wood', 'door_dark_oak', 'door_birch']
        const gmenu_drop = new ActionFormData()
        .title("%hostOption.teleport")
        .body("%menu.game - %hostOption.teleport")
        .button("§l§21st level", `textures/items/${doors[randomInt(0,6)]}`)
        .button("§l§62nd level", `textures/items/${doors[randomInt(0,6)]}`)
        .button("§l§c3rd level", `textures/items/${doors[randomInt(0,6)]}`)
         gmenu_drop.show(target).then(r => {
            if (r.selection == 0) {
                runcmd(`tp "${player}" @e[type=armor_stand:m,name=loc_tp1]`)
            } else if (r.selection == 1) {
                runcmd(`tp "${player}" @e[type=armor_stand:m,name=loc_tp2]`)
            } else if (r.selection == 2) {
                runcmd(`tp "${player}" @e[type=armor_stand:m,name=loc_tp3]`)
            }
        })
    }
})