import {ActionFormData, ActionFormResponse, MessageFormData, ModalFormData} from "@minecraft/server-ui";
import {Dimension, Player, world} from "@minecraft/server";
import {
  randomInt,
  showConfirmOpForm,
  runfunction,
  runcmd,
  getScore,
  hasTag,
  BoolToNum,
  arrayPlayers,
  tellraw,
  rawtext,
  textTag,
  runcmd_at
} from '../AbstractTools.js'
import { death_effects } from "../ui/death_effects";
import { pvp_kit1 } from "../mg/pvp_kit1.js";
import { buyEmerald } from "../AxisBank/index.js";

function setting_bw(target) {
  let name = target.nameTag
  let bw_copper = getScore("settings", "bw_copper");
  let bw_iron = getScore("settings", "bw_iron");
  let bw_gold = getScore("settings", "bw_gold");
  let bw_amethyst = getScore("settings", "bw_amethyst");
  let bw_kitstart = getScore("settings", "bw_kitstart");
  let bw_loot = getScore("settings", "bw_loot");
  let bw_enderchest = getScore("settings", "bw_enderchest");
  let bw_armor = getScore("settings", "bw_armor");
  let bw_kit = getScore("settings", "bw_kit");
  let ft_enderchest = Boolean(bw_enderchest);
  let ft_loot = Boolean(bw_loot);
  let ft_armor = Boolean(bw_armor);
  let ft_kit = Boolean(bw_kit);

  const bw_settings_main = new ActionFormData()
      .title("%howtoplay.gameSettings")
      .body("%howtoplay.gameSettings - BedWars")
      .button("%xyz.minecrafter.editor.see_more\n(%xyz.minecrafter.mods)", "textures/items/invisibility_wand.png")
      .button("%selectWorld.customizeType", "textures/items/settings.png")
      .button("%options.stream.ingest.reset", "textures/items/barrier")
  const bw_settings_set = new ModalFormData()
      .title("%howtoplay.gameSettings (BedWars)")
      .slider(" %item.copper_ingot.name (%gui.default: 5)", 1, 120, 1, bw_copper / 20)
      .slider(" %item.iron_ingot.name (%gui.default: 5)", 1, 120, 1, bw_iron / 20)
      .slider(" %item.gold_ingot.name (%gui.default: 15)", 1, 120, 1, bw_gold / 20)
      .slider(" %item.amethyst_shard.name (%gui.default: 30)", 1, 120, 1, bw_amethyst / 20)
      .toggle(" %tile.ender_chest.name", ft_enderchest)
      .toggle(" %axiscube.bedwars.settings.drop_loot_after_death", ft_loot)
      .toggle(" %axiscube.bedwars.settings.armor", ft_armor)
      .toggle(" %axiscube.bedwars.settings.kit_start", ft_kit)
      .slider(" %axiscube.bedwars.settings.kit_start.cooldown", 1, 300, 1, bw_kitstart / 20)
  const bw_settings_reset = new ModalFormData()
      .title("%controls.reset")
      .toggle("%xyz.minecrafter.editor.bw.generator: %item.copper_ingot.name")
      .toggle("%xyz.minecrafter.editor.bw.generator: %item.iron_ingot.name")
      .toggle("%xyz.minecrafter.editor.bw.generator: %item.gold_ingot.name")
      .toggle("%xyz.minecrafter.editor.bw.generator: %item.amethyst_shard.name")
      .toggle("Kit-start")
      .toggle("%axiscube.settings.reset_all", true)
  bw_settings_main.show(target).then(r => {
      if (r.selection == 0) {
          runcmd(`execute as "${name}" at "${name}" run function zz_games/bw/mods`);
      } else if (r.selection == 1) {
          bw_settings_set.show(target).then(d => {
              let [slider, slider2, slider3, slider4, toggle2, toggle3, toggle5, toggle6, slider5] = d.formValues
              runcmd(`scoreboard players set "bw_copper" settings ${slider * 20}`)
              runcmd(`scoreboard players set "bw_iron" settings ${slider2 * 20}`)
              runcmd(`scoreboard players set "bw_gold" settings ${slider3 * 20}`)
              runcmd(`scoreboard players set "bw_amethyst" settings ${slider4 * 20}`)
              runcmd(`scoreboard players set "bw_kitstart" settings ${slider5 * 20}`)
              runcmd(`scoreboard players set "bw_enderchest" settings ${BoolToNum(toggle2)}`)
              runcmd(`scoreboard players set "bw_loot" settings ${BoolToNum(toggle3)}`)
              runcmd(`scoreboard players set "bw_armor" settings ${BoolToNum(toggle5)}`)
              runcmd(`scoreboard players set "bw_kit" settings ${BoolToNum(toggle6)}`)
          })
      } else if (r.selection == 2) {
          bw_settings_reset.show(target).then(e => {
              let [reset_copper, reset_iron, reset_gold, reset_amethyst, reset_kit, reset_all] = e.formValues
              if (reset_copper) {
                  runcmd('scoreboard players set "bw_copper" settings 100')
              }
              if (reset_iron) {
                  runcmd('scoreboard players set "bw_iron" settings 100')
              }
              if (reset_gold) {
                  runcmd('scoreboard players set "bw_gold" settings 300')
              }
              if (reset_amethyst) {
                  runcmd('scoreboard players set "bw_amethyst" settings 600')
              }
              if (reset_kit) {
                  runcmd('scoreboard players set "bw_kitstart" settings 600')
              }
              if (reset_all) {
                  runcmd('scoreboard players set "bw_copper" settings 100')
                  runcmd('scoreboard players set "bw_iron" settings 100')
                  runcmd('scoreboard players set "bw_gold" settings 300')
                  runcmd('scoreboard players set "bw_amethyst" settings 600')
                  runcmd('scoreboard players set "bw_kitstart" settings 600')
                  runcmd('scoreboard players set "bw_kit" settings 1')
                  runcmd('scoreboard players set "bw_enderchest" settings 1')
                  runcmd('scoreboard players set "bw_loot" settings 1')
                  runcmd('scoreboard players set "bw_armor" settings 1')
              }
          })
      }
  })
}

function my_settings(target) {
    let name = target.nameTag
    const main = new ActionFormData()
      .title("%menu.settings")
      .body("%axiscube.menu.settings.my")
      .button("%options.music", "textures/ui/icons/music.png")
      .button("%xyz.minecrafter.particles_menu.name", "textures/ui/icons/particles.png")
      .button("%js.abstractscripts.settings.game_over_sound", "textures/blocks/jukebox_top")
      //.button("My records", "textures/blocks/gold_block")

    const records = new ActionFormData()
        .body(`My records (click for reset):`)
        .button(`Location`)

    const form_games_over = new ActionFormData()
      .title("%menu.settings")
      .body("%js.abstractscripts.settings.game_over_sound")
      .button(`%gui.default`, "textures/items/emerald")
      .button(`${textTag(target, 'settings.sound.adv', '\ue1c9', '')} %gui.default (0.7 pitch)`, "textures/items/emerald")
      .button(`${textTag(target, 'settings.sound.otherside', '\ue1c9', '')}${textTag(target, 'settings.sound.otherside.buy', '', '\ue12f')} Otherside ${textTag(target, 'settings.sound.otherside.buy', '', '(500)')}`, "textures/items/record_otherside")
      .button(`${textTag(target, 'settings.sound.pigstep', '\ue1c9', '')}${textTag(target, 'settings.sound.pigstep.buy', '', '\ue12f')} Pigstep ${textTag(target, 'settings.sound.pigstep.buy', '', '(500)')}`, "textures/items/record_pigstep")

    function link(l){
        if (l == 'main') {
            main.show(target).then(gg => {
                if (gg.selection == 0) {music_settings(target)}
                else if (gg.selection == 1) {death_effects(target)}
                else if (gg.selection == 2) {link('form_games_over')}
            })
        } else if (l == 'form_games_over') {
            form_games_over.show(target).then(gg => {
                if (gg.selection == 0) {
                    runcmd(`tag "${name}" remove settings.sound.adv`)
                    runcmd(`tag "${name}" remove settings.sound.pigstep`)
                    runcmd(`tag "${name}" remove settings.sound.otherside`)
                    runcmd_at(name, 'function zz_other/game_over_sound')
                } else if (gg.selection == 1) {
                    runcmd(`tag "${name}" add settings.sound.adv`)
                    runcmd(`tag "${name}" remove settings.sound.pigstep`)
                    runcmd(`tag "${name}" remove settings.sound.otherside`)
                    runcmd_at(name, 'function zz_other/game_over_sound')
                } else if (gg.selection == 2) {
                    if (hasTag(target, `settings.sound.otherside.buy`)) {
                        runcmd(`tag "${name}" remove settings.sound.adv`)
                        runcmd(`tag "${name}" remove settings.sound.pigstep`)
                        runcmd(`tag "${name}" add settings.sound.otherside`)
                        runcmd_at(name, 'function zz_other/game_over_sound')
                    } else {buyEmerald(target, 'Otherside', 500, [`tag "${name}" add settings.sound.otherside.buy`])}
                } else if (gg.selection == 3) {
                    if (hasTag(target, `settings.sound.pigstep.buy`)) {
                        runcmd(`tag "${name}" remove settings.sound.adv`)
                        runcmd(`tag "${name}" remove settings.sound.otherside`)
                        runcmd(`tag "${name}" add settings.sound.pigstep`)
                        runcmd_at(name, 'function zz_other/game_over_sound')
                    } else {buyEmerald(target, 'Pigstep', 500, [`tag "${name}" add settings.sound.pigstep.buy`])}
                }
            })
        }
    }
    link('main')
}

function music_settings(target) {
    
    let name = target.nameTag

  const my_music = new ModalFormData()
        .title("%menu.settings - %options.music")
        .dropdown("%xyz.minecrafter.settings.music\n\n§r%xyz.minecrafter.settings.music.volume", ["§4%options.off", "50\u0025", "100\u0025"], 2)

    my_music.show(target).then(mz => {
        let [music_volume] = mz.formValues
        if (music_volume == 0) {
            runcmd(`tag "${name}" add settings_music_off`);
            runcmd(`tag "${name}" remove settings_music_volume1`);
        } else if (music_volume == 1) {
            runcmd(`tag "${name}" remove settings_music_off`);
            runcmd(`tag "${name}" remove settings_music_volume1`);
        } else if (music_volume == 2) {
            runcmd(`tag "${name}" remove settings_music_off`);
            runcmd(`tag "${name}" add settings_music_volume1`);
        }
    })
}

function global_settings(target) {
    let name = target.nameTag
    const main = new ActionFormData()
      .title("%menu.settings")
      .body("%axiscube.menu.settings.global")
      .button("%xyz.minecrafter.menu.settings.map_reloading", "textures/ui/icons/reload.png")
      .button("%controls.reset", "textures/items/barrier.png")
      .button("%xyz.minecrafter.menu.perm.name", "textures/ui/icons/perms.png")
      .button("%axiscube.mg.lobby", "textures/ui/icons/lobby.png")
      .button("%createWorldScreen.game.settings", "textures/items/gamepad.png")
      .button("%js.abstractscripts.settings.hpbar", "textures/ui/heart_new")
      .button("%chat.settings", "textures/ui/icons/chat.png")

    const form_chat = new ModalFormData()
      .title('%chat.settings')
      .dropdown('%hostOption.time (Prefix)', ['%gui.none', 'HH:MM:SS', 'HH:MM'], getScore('settings', 'chat_time'))
      .slider('GMT', -12, 12, 1, getScore('settings', 'time_gmt'))

    const form_reset = new ActionFormData()
      .title("%menu.settings")
      .body("%xyz.minecrafter.settings.reset.descriptions\n\n%xyz.minecrafter.reset.descriptions")
      .button("%xyz.minecrafter.reset.stats", "textures/items/book_portfolio")
      .button("%xyz.minecrafter.reset.board", "textures/items/chalkboard_large")
      .button("%xyz.minecrafter.reset.offline", "textures/ui/Ping_Offline_Red_Dark")
      .button('%gui.back', `textures/ui/icons/back.png`)

    const form_lobby = new ActionFormData()
      .title("%menu.settings")
      .body("%menu.settings - %axiscube.mg.lobby")
      .button("%hostOption.time", "textures/ui/time_4sunset")
      .button('%gui.back', `textures/ui/icons/back.png`)

    const form_games = new ActionFormData()
      .title("%menu.settings")
      .body("%createWorldScreen.game.settings")
      .button("PVP Games", "textures/ui/icons/render/pvp.png")
      .button("BedWars", "textures/ui/icons/render/bw.png")
      .button('%gui.back', `textures/ui/icons/back.png`)

    const form_lobby_time = new ActionFormData()
      .title("%menu.settings")
      .body("%menu.settings - %axiscube.mg.lobby")
      .button("%hostOption.time.sunrise", "textures/ui/time_1sunrise")
      .button("%hostOption.time.day", "textures/ui/time_2day")
      .button("%hostOption.time.noon", "textures/ui/time_3noon")
      .button("%hostOption.time.sunset", "textures/ui/time_4sunset")
      .button("%hostOption.time.night", "textures/ui/time_5night")
      .button("%hostOption.time.midnight", "textures/ui/time_6midnight")

    const form_perms = new ActionFormData()
      .title("%xyz.minecrafter.menu.perm.name")
      .button('%permissions.title (%stat.generalButton)', 'textures/ui/icons/2pls.png')
      .button('%permissions.popup.title', `textures/ui/icons/skin_picture/${randomInt(1,2)}.png`)
      .button('%gui.back', `textures/ui/icons/back.png`)

    const form_perms_add = new MessageFormData()
      .title("%permissions.title")
      .body("%js.abstractscripts.settings.be_op")
      .button1("%gui.confirm")
      .button2("%gui.cancel")

    const form_perms_remove = new MessageFormData()
      .title("%permissions.title")
      .body("%js.abstractscripts.settings.de_op")
      .button1("%gui.confirm")
      .button2("%gui.cancel")

    const form_perms_plc = new ModalFormData()
      .title("%xyz.minecrafter.menu.perm.name")
      .dropdown('%axiscube.mode.choice_player', arrayPlayers())

    const form_perms_generic = new ModalFormData()
      .title("%xyz.minecrafter.menu.perm.name")
      .dropdown("%xyz.minecrafter.settings.perm.start.description.more", [" §2%xyz.minecrafter.settings.perm.tier.all", " §4%xyz.minecrafter.settings.perm.tier.only_me"], 0)
      .dropdown("\n%xyz.minecrafter.settings.perm.stop.description.more", [" §2%xyz.minecrafter.settings.perm.tier.all", " §4%xyz.minecrafter.settings.perm.tier.only_me"], 0)
      .dropdown("\n%xyz.minecrafter.settings.perm.game.description.more", [" §2%xyz.minecrafter.settings.perm.tier.all", " §4%xyz.minecrafter.settings.perm.tier.only_me"], 0)

    const form_reload = new MessageFormData()
      .title("%xyz.minecrafter.menu.dialogue.confirmation")
      .body("%xyz.minecrafter.menu.settings.map_reloading.description")
      .button1("%gui.yes")
      .button2("%gui.cancel")
    
    function link(l) {
        if (l == 'main') {
            main.show(target).then(gg => {
                if (gg.selection == 0) {link('form_reload')}
                else if (gg.selection == 1) link('form_reset')
                else if (gg.selection == 2) link('form_perms')
                else if (gg.selection == 3) link('form_lobby')
                else if (gg.selection == 4) link('form_games')
                else if (gg.selection == 5) link('form_hp')
                else if (gg.selection == 6) link('form_chat')
            })
        } else if (l == 'form_reload') {
            form_reload.show(target).then(gg => {if (gg.selection == 1) runfunction('reload')})
        } else if (l == 'form_reset') {
            form_reset.show(target).then(gg => {
                if (gg.selection == 0) runcmd(`execute as "${name}" at "${name}" run function reset_stats`)
                else if (gg.selection == 1) runcmd(`execute as "${name}" at "${name}" run function reset`)
                else if (gg.selection == 2) runcmd(`execute as "${name}" at "${name}" run function reset_offline`)
                else if (gg.selection == 3) link('main')
            })
        } else if (l == 'form_perms') {
            form_perms.show(target).then(gg => {
                if (gg.selection == 0) link('form_perms_generic')
                else if (gg.selection == 1 && hasTag(target, 'global_operator_main')) link('form_perms_plr')
                else if (gg.selection == 1 && !hasTag(target, 'global_operator_main')) tellraw(`{"rawtext":[{"text":"§c"},{"translate":"xyz.minecrafter.noperm"}]}`, name)
                else if (gg.selection == 2) link('main')
            })
        } else if (l == 'form_perms_generic') {
            form_perms_generic.show(target).then(gg => {
                let [startgame, stopgame, managegame] = gg.formValues;
                if (startgame == 0) {runcmd('setblock -5 1 -5 redstone_block')}
                else {runcmd('setblock -5 2 -5 redstone_block')}

                if (stopgame == 0) {runcmd('setblock -5 1 -3 redstone_block')}
                else {runcmd('setblock -5 2 -3 redstone_block')}

                if (managegame == 0) {runcmd('setblock -5 1 -1 redstone_block')}
                else { runcmd('setblock -5 2 -1 redstone_block')}
            })
        } else if (l == 'form_perms_plr') {
            form_perms_plc.show(target).then(gg => {
                let [selected_player] = gg.formValues
                let selected_player_target = [...world.getPlayers()][selected_player]
                let selected_player_name = Array.from(world.getPlayers(),plr=>plr.name)[selected_player]
                if(hasTag(selected_player_target, 'global_operator')) {
                    form_perms_remove.show(target).then(gg => {
                        if (gg.selection == 1 && selected_player_target != target) {
                            tellraw(`{"rawtext":[{"translate":"js.abstractscripts.settings.de_op.msg","with":["${selected_player_name}"]}]}`, '@a')
                            runcmd(`tag "${selected_player_name}" remove global_operator`)
                            runcmd(`tag "${selected_player_name}" remove perm_managegame`)
                            runcmd(`tag "${selected_player_name}" remove perm_startgame`)
                            runcmd(`tag "${selected_player_name}" remove perm_stopgame`)
                        } else if (selected_player_target == target) {
                            rawtext('js.abstractscripts.me.vs.me', name, 'translate')
                        }
                    })
                } else if(!hasTag(selected_player_target, 'global_operator')) {
                    form_perms_add.show(target).then(gg => {
                        if (gg.selection == 1) {
                            tellraw(`{"rawtext":[{"translate":"js.abstractscripts.settings.be_op.msg","with":["${selected_player_name}"]}]}`, '@a')
                            runcmd(`tag "${selected_player_name}" add global_operator`)
                        }
                    })
                } else runcmd(`tellraw "${name}" {"rawtext":[{"text":"§c"},{"translate":"xyz.minecrafter.noperm"}]}`)
            })
        } else if (l == 'form_lobby') {
            form_lobby.show(target).then(gg => {if (gg.selection == 0) {link('form_lobby_time')} else if (gg.selection == 1) {link('main')}})
        } else if (l == 'form_lobby_time') {
            form_lobby_time.show(target).then(gg => {
                if (gg.selection == 0) {
                    if (getScore('debug', 'minigame') == 0) {runcmd('time set sunrise');runcmd('scoreboard players set time settings 1');link('form_lobby_time')}
                } else if (gg.selection == 1) {
                    if (getScore('debug', 'minigame') == 0) {runcmd('time set day');runcmd('scoreboard players set time settings 2');link('form_lobby_time')}
                } else if (gg.selection == 2) {
                    if (getScore('debug', 'minigame') == 0) {runcmd('time set noon');runcmd('scoreboard players set time settings 0');link('form_lobby_time')}
                } else if (gg.selection == 3) {
                    if (getScore('debug', 'minigame') == 0) {runcmd('time set sunset');runcmd('scoreboard players set time settings 3');link('form_lobby_time')}
                } else if (gg.selection == 4) {
                    if (getScore('debug', 'minigame') == 0) {runcmd('time set night');runcmd('scoreboard players set time settings 4');link('form_lobby_time')}
                } else if (gg.selection == 5) {
                    if (getScore('debug', 'minigame') == 0) {runcmd('time set midnight'); runcmd('scoreboard players set time settings 5');link('form_lobby_time')}
                }
            })
        } else if (l == 'form_games') {
            form_games.show(target).then(gg => {
                if (gg.selection == 0) {pvp_kit1(target)} else if (gg.selection == 1) {setting_bw(target)} else if (gg.selection == 2) {link('main')}
            })
        } else if (l == 'form_hp') {
            const form_hp = new ModalFormData()
                .title('\ue1d4\ue1d6\ue1d5 %js.abstractscripts.settings.hpbar')
                .toggle("\ue1a8 %js.abstractscripts.settings.hpbar.swords", Boolean(getScore('settings', 'hp_sword')))
                .toggle("\ue19a %js.abstractscripts.settings.hpbar.bows", Boolean(getScore('settings', 'hp_bow')))
            
            form_hp.show(target).then(gg => {
                let [sword, bow] = gg.formValues
                runcmd(`scoreboard players set "hp_sword" settings ${BoolToNum(sword)}`)
                runcmd(`scoreboard players set "hp_bow" settings ${BoolToNum(bow)}`)
            })
        } else if (l == 'form_chat') {
            form_chat.show(target).then(gg => {
                let [time_on, gmt] = gg.formValues
                runcmd(`scoreboard players set "chat_time" settings ${time_on}`)
                runcmd(`scoreboard players set "time_gmt" settings ${gmt}`)
            })
        }
    }
    try{showConfirmOpForm('Global Settings', target, 'AxisCube LLC', function(answer) {if (answer == 1) link('main')})}catch(err){console.error(err)}
}

function settings_form(target) {

    let name = target.nameTag

  const settingsel = new ActionFormData()
      .title("%menu.settings")
      .body("%axiscube.menu.settings.about")
      .button("%axiscube.menu.settings.global", "textures/ui/icons/players.png") //global
      .button(`%axiscube.menu.settings.my\n§o(Only ${name})`, "textures/ui/icons/1pl.png") //my

  settingsel.show(target).then(setsel => {
      if (setsel.selection == 0) {
          global_settings(target)
      }
      if (setsel.selection == 1) {
        my_settings(target)
      }
  })
}
export {
  settings_form,
  setting_bw,
  music_settings
}